####################################
# Burncenter
# Copyright(c) 2000, 2001, 2002 Alexandre Janon <alexandre12@mageos.com>
##
# Burncenter.pm
##

package Burncenter;

## Ask for something

sub getline {
	my $question = shift;
	my $default = shift;

	print translatestring("$question ");
	print "[default=$default] " if $default ne '';

	$answer = <>;
	
	if($answer eq "\n") {
		$answer = $default;
	}
	chomp $answer;
	return $answer;
}

sub getlinebasedonconfig {
	my $question = shift;
	my $confvar = shift;
	my $default = shift;

	my $var = getconfig($confvar);
	if($var eq '') {
		return getline($question,$default);
	} else {
		return getline($question,$var);
	}
}

## Gets the translated version of a string

sub translatestring {
	my $string = shift;
	my $language = getconfig("lang");
	my $tr;

	open(LANGFILE, "/usr/share/burncenter3/lang.$language") or return $string;
	while(<LANGFILE>) {
		/^$string=(.+)$/;
		if($1 ne '') {
			$tr = $1;
		}
	}
	chomp $tr;
	if($tr eq '' or $tr eq ' ') {
		$tr = $string;
	}
	close(LANGFILE);
	return $tr;
}

## Gets a config variable

sub getconfig {
	my $what = shift;

	open(CONFFILE, "/etc/burncenter.conf");
	while(<CONFFILE>) {
		/^$what=(.+)/;
		if($1 ne '') {
			$ret = $1;
		}
	}
	close(CONFFILE);
	return $ret;
}

## Makes an image of the CD currently in the cdreader and returns the name of the image

sub makecdimage {
	my $tmpfiles=getconfig("tempfiles");
	my $name = "$tmpfiles/cdimage.$$";
	$cdreader=getconfig("cdreader");
	system("cp $cdreader $name");
	return $name;
}	

## Copies all tracks on an audio CD to a directory, returns the name of this dir

sub copyalltracks {
	my $dirname=getconfig("tempfiles")."/audiofiles.$$";
	mkdir $dirname;
	my $cdda2wav=getconfig("cdda2wav");
	my $dev=getconfig("dev");
	system("cd $dirname ; $cdda2wav -t1 -B -D$dev ; rm -f *.inf ; cd -");
	return $dirname;
}

## Converts an entire directory of MP3s or OGGs to WAVes files, and then normalize them

sub mp3towav {
	my $dirname=shift;

	my $mpg123=getconfig("mpg123");
	my $ogg123=getconfig("ogg123");
	my $normalize=getconfig("normalize");
	opendir(DIR,$dirname);
	@mp3files = grep(/\.mp3$/i,readdir(DIR));
	for $file(@mp3files) {
		system("cd $dirname ; $mpg123 -r44100 --stereo -w '$file.wav' '$file' ; cd -");
	}
	closedir(DIR);
	opendir(DIR,$dirname);
	@oggfiles = grep(/\.ogg$/i,readdir(DIR));
	for $file(@oggfiles) {
		system("cd $dirname ; $ogg123 -d wav -f '$file.wav' '$file' ; cd -");
	}
	closedir(DIR);
	system("cd $dirname ; $normalize -m *.wav ; cd -"); 
}

## Burns an image on CD. It is possible to specify additionnal cdrecord flags (eg -multi)

sub burncdimage {
	my $image = shift;
	my $cdrecordflags = shift;

	my $cdrecord=getconfig("cdrecord");
	my $speed=getconfig("speed");
	my $dev=getconfig("dev");

	system("$cdrecord -eject -v speed=$speed dev=$dev $cdrecordflags $image");
}

## Burns all the WAVes files in a given directory

sub burnwavfiles {
	my $directory = shift;

	my $cdrecord=getconfig("cdrecord");
	my $dev=getconfig("dev");
	my $speed=getconfig("speed");

       	system("$cdrecord -eject -v speed=$speed dev=$dev -pad -audio $directory/*.wav");
}

## Blanks a CDRW 

sub blankcdrw {
	my $blank = shift;

	my $cdrecord=getconfig("cdrecord");
	my $speed=getconfig("speed");
	my $dev=getconfig("dev");

	system("$cdrecord -eject -v speed=$speed dev=$dev blank=$blank");
}

## Creates a (first-session) Rockridge/Joliet ISO image of a given directory, and returns the name of this image

sub makefirstisoimage {
	my $directory = shift;

	my $name=getconfig("tempfiles")."/isoimage.$$";
	my $mkisofs=getconfig("mkisofs");

	system("$mkisofs -v -o $name -J -R $directory");

	return $name;
}

## Same as makefirstisoimage, except we import the precedent sessions first 

sub makesecondisoimage {
	my $directory = shift;

	my $name=getconfig("tempfiles")."/isoimage.$$";
	my $cdrecord=getconfig("cdrecord");
	my $dev=getconfig("dev");
	my $cdwriter=getconfig("cdwriter");
	my $mkisofs=getconfig("mkisofs");

	my $msinfo=`$cdrecord dev=$dev -msinfo`;
	chomp $msinfo;
	system("$mkisofs -v -o $name -J -R -M$cdwriter -C$msinfo $directory");

	return $name;
}

## Check if the disc has other sessions written. Returns 0 if no other session
## was written, and 1 if other sessions have been written.

sub checkothersessions {
	my $cdrecord=getconfig("cdrecord");
	my $dev=getconfig("dev");

	my $msinfo=`$cdrecord dev=$dev -msinfo 2>/dev/null`;

	return 0 if $msinfo eq '';
	return 1 if $msinfo ne '';
}

## Copy a given playlist to a directory; returns the name of this directory

sub playlist2dir {
	my $playlist = shift;

	my $dirname = getconfig("tempfiles")."/playlist.$$";
	mkdir $dirname;
	open(PLAYLIST, $playlist) || return "";
	while(<PLAYLIST>) {
		next if /^#/;
		next if ($_ eq '');
		chomp;
		system("cp $_ $dirname");
	}

	return $dirname;
}

1;
